Documentation
¶
Overview ¶
Package velo is a lightweight framework for building desktop applications with web frontends. It provides native webview, system tray, file dialogs, and error dialogs across macOS, Windows, and Linux.
Index ¶
- type AppConfig
- type Box
- type BoxContext
- func (c *BoxContext) Args() interface{}
- func (c *BoxContext) BindJSON(obj interface{}) error
- func (c *BoxContext) Context() context.Context
- func (c *BoxContext) Deadline() (deadline time.Time, ok bool)
- func (c *BoxContext) Done() <-chan struct{}
- func (c *BoxContext) Err() error
- func (c *BoxContext) Error(message string) string
- func (c *BoxContext) GetHeader(key string) string
- func (c *BoxContext) ID() string
- func (c *BoxContext) Method() string
- func (c *BoxContext) Ok(data interface{}) string
- func (c *BoxContext) Query(key string) string
- func (c *BoxContext) SetContext(ctx context.Context)
- func (c *BoxContext) SetQuery(query map[string]string)
- func (c *BoxContext) Value(key interface{}) interface{}
- type BoxResult
- type H
- type Handler
- type Mode
- type VeloAppOpt
- type VeloWebviewOpt
Constants ¶
This section is empty.
Variables ¶
This section is empty.
Functions ¶
This section is empty.
Types ¶
type AppConfig ¶
type AppConfig struct {
App struct {
Name string `json:"name"`
DisplayName string `json:"display_name"`
} `json:"app"`
Update buildcfg.UpdateSection `json:"update"`
}
func LoadAppConfig ¶
type Box ¶
func NewApp ¶
func NewApp(o *VeloAppOpt) *Box
func (*Box) NewWebview ¶
func (b *Box) NewWebview(opt *VeloWebviewOpt) *webview.Webview
func (*Box) OpenWindow ¶
func (b *Box) OpenWindow(opt *VeloWebviewOpt) *webview.Webview
func (*Box) SendMessage ¶
type BoxContext ¶
type BoxContext struct {
Writer http.ResponseWriter
// contains filtered or unexported fields
}
func (*BoxContext) Args ¶
func (c *BoxContext) Args() interface{}
func (*BoxContext) BindJSON ¶
func (c *BoxContext) BindJSON(obj interface{}) error
func (*BoxContext) Context ¶
func (c *BoxContext) Context() context.Context
func (*BoxContext) Done ¶
func (c *BoxContext) Done() <-chan struct{}
func (*BoxContext) Err ¶
func (c *BoxContext) Err() error
func (*BoxContext) Error ¶
func (c *BoxContext) Error(message string) string
func (*BoxContext) GetHeader ¶
func (c *BoxContext) GetHeader(key string) string
func (*BoxContext) ID ¶
func (c *BoxContext) ID() string
func (*BoxContext) Method ¶
func (c *BoxContext) Method() string
func (*BoxContext) Ok ¶
func (c *BoxContext) Ok(data interface{}) string
func (*BoxContext) Query ¶
func (c *BoxContext) Query(key string) string
func (*BoxContext) SetContext ¶
func (c *BoxContext) SetContext(ctx context.Context)
func (*BoxContext) SetQuery ¶
func (c *BoxContext) SetQuery(query map[string]string)
func (*BoxContext) Value ¶
func (c *BoxContext) Value(key interface{}) interface{}
type Handler ¶
type Handler func(c *BoxContext) interface{}
type VeloAppOpt ¶
Click to show internal directories.
Click to hide internal directories.